import PropTypes from "prop-types";
import Image from "next/image";
import Link from "next/link";
import Icons from "@components/base/icons";
import styles from "./styles.module.css";

const Card = ({
  title,
  description,
  image,
  publishedDate,
  author,
  images,
  readingTime,
}) => {
  return (
    <div className={styles.card}>
      <Link href="#">
        <Image
          className={styles.img}
          src={image.url}
          height={image.height}
          width={image.width}
          alt={title}
        />
        <p className={styles.title}>{title}</p>
      </Link>
      <div className={styles.authorcontainer}>
        <p className={styles.description}>{description}</p>
        <div className={styles.cardbottom}>
          <Image
            className={styles.img}
            src={images.url}
            height={images.height}
            width={images.width}
            alt={author}
          />
          <div className={styles.authordescription}>
            <p className={styles.authorName}>{author}</p>
            <div className={styles["author-desc"]}>
              {publishedDate}
              <span className={styles.icon}>
                <Icons name="clock" size="small" />
                {readingTime}
              </span>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};
Card.propTypes = {
  title: PropTypes.string,
  description: PropTypes.string,
  image: PropTypes.shape({
    url: PropTypes.string,
  }),
  publishedDate: PropTypes.string,
  author: PropTypes.string,
  images: PropTypes.shape({
    url: PropTypes.string, // Use PropTypes.string for images
  }),

  readingTime: PropTypes.string,
};

export default Card;
